# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from iblai.models.api_token_cost import APITokenCost
from iblai.models.ai_account_orgs_use_default_llm_key_create200_response import AiAccountOrgsUseDefaultLlmKeyCreate200Response
from iblai.models.ai_account_orgs_users_free_trial_retrieve200_response import AiAccountOrgsUsersFreeTrialRetrieve200Response
from iblai.models.credential_request import CredentialRequest
from iblai.models.iblai_platform_meta import IBLAIPlatformMeta
from iblai.models.iblai_platform_meta_request import IBLAIPlatformMetaRequest
from iblai.models.iblai_platform_meta_update_request import IBLAIPlatformMetaUpdateRequest
from iblai.models.integration_credential import IntegrationCredential
from iblai.models.llm_credential_request import LLMCredentialRequest
from iblai.models.llm_credential_response import LLMCredentialResponse
from iblai.models.patched_credential_request import PatchedCredentialRequest
from iblai.models.patched_llm_credential_request import PatchedLLMCredentialRequest
from iblai.models.use_main_creds import UseMainCreds

from iblai.api_client import ApiClient, RequestSerialized
from iblai.api_response import ApiResponse
from iblai.rest import RESTResponseType


class AiAccountApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def ai_account_orgs_credential_create(
        self,
        org: StrictStr,
        llm_credential_request: LLMCredentialRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_credential_create

        Create a new LLM credential for an organization.  Args:     request: The HTTP request containing credential information     org: Organization key identifier  Returns:     Response: Created LLM credential  Raises:     NotFound: When organization is not found     ValidationError: When request data is invalid

        :param org: (required)
        :type org: str
        :param llm_credential_request: (required)
        :type llm_credential_request: LLMCredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_credential_create_serialize(
            org=org,
            llm_credential_request=llm_credential_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LLMCredentialResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_credential_create_serialize(
        self,
        org,
        llm_credential_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if llm_credential_request is not None:
            _body_params = llm_credential_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-account/orgs/{org}/credential/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_credential_partial_update(
        self,
        org: StrictStr,
        patched_llm_credential_request: Optional[PatchedLLMCredentialRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_credential_partial_update

        Update an existing LLM credential for an organization.  Args:     request: The HTTP request containing updated credential information     org: Organization key identifier  Returns:     Response: Updated LLM credential  Raises:     NotFound: When organization or credential is not found     ValidationError: When request data is invalid

        :param org: (required)
        :type org: str
        :param patched_llm_credential_request:
        :type patched_llm_credential_request: PatchedLLMCredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_credential_partial_update_serialize(
            org=org,
            patched_llm_credential_request=patched_llm_credential_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LLMCredentialResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_credential_partial_update_serialize(
        self,
        org,
        patched_llm_credential_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_llm_credential_request is not None:
            _body_params = patched_llm_credential_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/ai-account/orgs/{org}/credential/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_credential_retrieve(
        self,
        org: StrictStr,
        name: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Filter credentials by provider name (e.g., 'openai', 'google')")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_credential_retrieve

        Retrieve LLM credentials for an organization.  Query Parameters:     name (optional): Filter results by LLM provider name  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: List of LLM credentials for the organization  Raises:     NotFound: When organization is not found or when no credentials match the filters     ValidationError: When query parameters are invalid

        :param org: (required)
        :type org: str
        :param name: Filter credentials by provider name (e.g., 'openai', 'google')
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_credential_retrieve_serialize(
            org=org,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "LLMCredentialResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_credential_retrieve_serialize(
        self,
        org,
        name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if name is not None:
            
            _query_params.append(('name', name))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-account/orgs/{org}/credential/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_integration_credential_create(
        self,
        org: StrictStr,
        credential_request: CredentialRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_integration_credential_create

        Create a new integration credential for an organization.  Args:     request: The HTTP request containing credential information     org: Organization key identifier  Returns:     Response: Created integration credential  Raises:     NotFound: When organization is not found     ValidationError: When request data is invalid

        :param org: (required)
        :type org: str
        :param credential_request: (required)
        :type credential_request: CredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_integration_credential_create_serialize(
            org=org,
            credential_request=credential_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IntegrationCredential",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_integration_credential_create_serialize(
        self,
        org,
        credential_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if credential_request is not None:
            _body_params = credential_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-account/orgs/{org}/integration-credential/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_integration_credential_partial_update(
        self,
        org: StrictStr,
        patched_credential_request: Optional[PatchedCredentialRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_integration_credential_partial_update

        Update an existing integration credential for an organization.  Args:     request: The HTTP request containing updated credential information     org: Organization key identifier  Returns:     Response: Updated integration credential  Raises:     NotFound: When organization or credential is not found     ValidationError: When request data is invalid

        :param org: (required)
        :type org: str
        :param patched_credential_request:
        :type patched_credential_request: PatchedCredentialRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_integration_credential_partial_update_serialize(
            org=org,
            patched_credential_request=patched_credential_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IntegrationCredential",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_integration_credential_partial_update_serialize(
        self,
        org,
        patched_credential_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if patched_credential_request is not None:
            _body_params = patched_credential_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/api/ai-account/orgs/{org}/integration-credential/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_integration_credential_retrieve(
        self,
        org: StrictStr,
        name: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Filter credentials by provider name (e.g., 'openai', 'google')")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_integration_credential_retrieve

        Retrieve integration credentials for an organization.  Query Parameters:     name (optional): Filter results by integration service name  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: List of integration credentials for the organization  Raises:     NotFound: When organization is not found or when no credentials match the filters     ValidationError: When query parameters are invalid

        :param org: (required)
        :type org: str
        :param name: Filter credentials by provider name (e.g., 'openai', 'google')
        :type name: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_integration_credential_retrieve_serialize(
            org=org,
            name=name,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IntegrationCredential",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_integration_credential_retrieve_serialize(
        self,
        org,
        name,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if name is not None:
            
            _query_params.append(('name', name))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-account/orgs/{org}/integration-credential/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_platform_metadata_create(
        self,
        org: StrictStr,
        iblai_platform_meta_request: IBLAIPlatformMetaRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_platform_metadata_create

        Create or update platform metadata for a specific organization.  Args:     request: The HTTP request containing metadata information     org: Organization key identifier  Returns:     Response: Created/updated platform metadata  Raises:     NotFound: When platform is not found     ValidationError: When request data is invalid

        :param org: (required)
        :type org: str
        :param iblai_platform_meta_request: (required)
        :type iblai_platform_meta_request: IBLAIPlatformMetaRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_platform_metadata_create_serialize(
            org=org,
            iblai_platform_meta_request=iblai_platform_meta_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '201': "IBLAIPlatformMeta",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_platform_metadata_create_serialize(
        self,
        org,
        iblai_platform_meta_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if iblai_platform_meta_request is not None:
            _body_params = iblai_platform_meta_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-account/orgs/{org}/platform-metadata/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_platform_metadata_list(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_platform_metadata_list

        Retrieve platform metadata for a specific organization.  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: Platform metadata including service configurations and active services  Raises:     NotFound: When platform metadata is not found

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_platform_metadata_list_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[IBLAIPlatformMeta]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_platform_metadata_list_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-account/orgs/{org}/platform-metadata/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_platform_metadata_update(
        self,
        org: StrictStr,
        iblai_platform_meta_update_request: Optional[IBLAIPlatformMetaUpdateRequest] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_platform_metadata_update

        Update specific fields of platform metadata for an organization.  This endpoint allows updating the active LLM provider and available LLMs.  Args:     request: The HTTP request containing update information     org: Organization key identifier  Returns:     Response: Updated platform metadata  Raises:     NotFound: When platform metadata is not found     ValidationError: When request data is invalid

        :param org: (required)
        :type org: str
        :param iblai_platform_meta_update_request:
        :type iblai_platform_meta_update_request: IBLAIPlatformMetaUpdateRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_platform_metadata_update_serialize(
            org=org,
            iblai_platform_meta_update_request=iblai_platform_meta_update_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[IBLAIPlatformMeta]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_platform_metadata_update_serialize(
        self,
        org,
        iblai_platform_meta_update_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if iblai_platform_meta_update_request is not None:
            _body_params = iblai_platform_meta_update_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='PUT',
            resource_path='/api/ai-account/orgs/{org}/platform-metadata/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_tokens_list(
        self,
        org: StrictStr,
        session_id: Annotated[Optional[StrictStr], Field(description="Filter token usage by specific chat session ID")] = None,
        username: Annotated[Optional[Annotated[str, Field(min_length=1, strict=True)]], Field(description="Filter token usage by specific username")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_tokens_list

        Retrieve weekly token usage statistics for an organization.  Query Parameters:     username (optional): Filter results by specific username     session_id (optional): Filter results by specific session ID  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: List of weekly token usage records with prompt and completion tokens  Raises:     NotFound: When organization is not found or when no sessions match the filters     ValidationError: When query parameters are invalid

        :param org: (required)
        :type org: str
        :param session_id: Filter token usage by specific chat session ID
        :type session_id: str
        :param username: Filter token usage by specific username
        :type username: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_tokens_list_serialize(
            org=org,
            session_id=session_id,
            username=username,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "List[APITokenCost]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_tokens_list_serialize(
        self,
        org,
        session_id,
        username,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        if session_id is not None:
            
            _query_params.append(('session_id', session_id))
            
        if username is not None:
            
            _query_params.append(('username', username))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-account/orgs/{org}/tokens/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_use_default_llm_key_create(
        self,
        org: StrictStr,
        use_main_creds: UseMainCreds,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_use_default_llm_key_create

        Enable or disable the use of main LLM credentials for an organization.  Request Body:     enable (boolean): Set to true to enable main credentials     disable (boolean): Set to true to disable main credentials  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: Confirmation message  Raises:     ValidationError: When neither enable nor disable is specified

        :param org: (required)
        :type org: str
        :param use_main_creds: (required)
        :type use_main_creds: UseMainCreds
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_use_default_llm_key_create_serialize(
            org=org,
            use_main_creds=use_main_creds,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AiAccountOrgsUseDefaultLlmKeyCreate200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_use_default_llm_key_create_serialize(
        self,
        org,
        use_main_creds,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if use_main_creds is not None:
            _body_params = use_main_creds


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-account/orgs/{org}/use-default-llm-key/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_use_free_trial_create(
        self,
        org: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_use_free_trial_create

        Enable, disable, or update free trial settings for an organization.  Request Body:     enable (boolean): Set to true to enable free trial     disable (boolean): Set to true to disable free trial     metadata (object, optional): Additional metadata for the free trial  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: Confirmation message

        :param org: (required)
        :type org: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_use_free_trial_create_serialize(
            org=org,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_use_free_trial_create_serialize(
        self,
        org,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/api/ai-account/orgs/{org}/use-free-trial/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_users_default_llm_key_usage_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_users_default_llm_key_usage_retrieve

        Retrieve the status of main LLM credential usage for an organization.  Args:     request: The HTTP request     org: Organization key identifier     user_id: User identifier  Returns:     Response: Status of main LLM credential usage

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_users_default_llm_key_usage_retrieve_serialize(
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_users_default_llm_key_usage_retrieve_serialize(
        self,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter




        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-account/orgs/{org}/users/{user_id}/default-llm-key-usage',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def ai_account_orgs_users_free_trial_retrieve(
        self,
        org: StrictStr,
        user_id: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """ai_account_orgs_users_free_trial_retrieve

        Retrieve the free trial status for an organization.  Args:     request: The HTTP request     org: Organization key identifier  Returns:     Response: Free trial status (boolean)  Raises:     NotFound: When organization is not found

        :param org: (required)
        :type org: str
        :param user_id: (required)
        :type user_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._ai_account_orgs_users_free_trial_retrieve_serialize(
            org=org,
            user_id=user_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "AiAccountOrgsUsersFreeTrialRetrieve200Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _ai_account_orgs_users_free_trial_retrieve_serialize(
        self,
        org,
        user_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, Union[str, bytes]] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if org is not None:
            _path_params['org'] = org
        if user_id is not None:
            _path_params['user_id'] = user_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'PlatformApiKeyAuthentication'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/ai-account/orgs/{org}/users/{user_id}/free-trial',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.paginated_assertions_response import PaginatedAssertionsResponse

class TestPaginatedAssertionsResponse(unittest.TestCase):
    """PaginatedAssertionsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedAssertionsResponse:
        """Test PaginatedAssertionsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedAssertionsResponse`
        """
        model = PaginatedAssertionsResponse()
        if include_optional:
            return PaginatedAssertionsResponse(
                next = '',
                previous = '',
                count = 56,
                num_pages = 56,
                page_number = 56,
                max_page_size = 56,
                data = [
                    iblai.models.assertion.Assertion(
                        entity_id = '', 
                        issued_on = '', 
                        credential_details = {
                            'key' : ''
                            }, 
                        recipient = {
                            'key' : ''
                            }, 
                        metadata = null, 
                        course = {
                            'key' : ''
                            }, 
                        program = {
                            'key' : ''
                            }, 
                        narrative = '', 
                        revoked = True, 
                        revocation_reason = '', 
                        acceptance = 'Unaccepted', 
                        expires = '', )
                    ]
            )
        else:
            return PaginatedAssertionsResponse(
                next = '',
                previous = '',
                count = 56,
                num_pages = 56,
                page_number = 56,
                max_page_size = 56,
                data = [
                    iblai.models.assertion.Assertion(
                        entity_id = '', 
                        issued_on = '', 
                        credential_details = {
                            'key' : ''
                            }, 
                        recipient = {
                            'key' : ''
                            }, 
                        metadata = null, 
                        course = {
                            'key' : ''
                            }, 
                        program = {
                            'key' : ''
                            }, 
                        narrative = '', 
                        revoked = True, 
                        revocation_reason = '', 
                        acceptance = 'Unaccepted', 
                        expires = '', )
                    ],
        )
        """

    def testPaginatedAssertionsResponse(self):
        """Test PaginatedAssertionsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_marketing_api import AiMarketingApi


class TestAiMarketingApi(unittest.TestCase):
    """AiMarketingApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiMarketingApi()

    def tearDown(self) -> None:
        pass

    def test_ai_marketing_orgs_users_heygen_videos_create(self) -> None:
        """Test case for ai_marketing_orgs_users_heygen_videos_create

        """
        pass

    def test_ai_marketing_orgs_users_heygen_videos_list(self) -> None:
        """Test case for ai_marketing_orgs_users_heygen_videos_list

        """
        pass

    def test_ai_marketing_orgs_users_heygen_videos_retrieve(self) -> None:
        """Test case for ai_marketing_orgs_users_heygen_videos_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.conversations import Conversations

class TestConversations(unittest.TestCase):
    """Conversations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Conversations:
        """Test Conversations
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Conversations`
        """
        model = Conversations()
        if include_optional:
            return Conversations(
                id = '',
                messages = '',
                topics = [
                    iblai.models.topic_model.TopicModel(
                        name = '', )
                    ],
                sentiment = '',
                mentor = '',
                student = '',
                model = '',
                rating = '',
                inserted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                has_document = True,
                memory_tracked = True,
                llm_name = '',
                llm_provider = '',
                metadata = None,
                platform = 56
            )
        else:
            return Conversations(
                id = '',
                messages = '',
                topics = [
                    iblai.models.topic_model.TopicModel(
                        name = '', )
                    ],
                sentiment = '',
                mentor = '',
                student = '',
                model = '',
                rating = '',
                inserted_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testConversations(self):
        """Test Conversations"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ItemTypeEnum(str, Enum):
    """
    * `course` - Course * `unit` - Unit * `resource` - Resource * `course_unit` - Course and Unit * `course_resource` - Course and Resource * `unit_resource` - Unit and Resource * `all` - Course, Unit, and Resource
    """

    """
    allowed enum values
    """
    COURSE = 'course'
    UNIT = 'unit'
    RESOURCE = 'resource'
    COURSE_UNIT = 'course_unit'
    COURSE_RESOURCE = 'course_resource'
    UNIT_RESOURCE = 'unit_resource'
    ALL = 'all'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ItemTypeEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PathwayEnrollmentPlus(BaseModel):
    """
    Includes metadata+
    """ # noqa: E501
    user_id: Optional[StrictInt] = None
    username: Optional[StrictStr] = None
    pathway_id: Optional[StrictStr] = None
    pathway_uuid: Optional[StrictStr] = None
    platform_key: Optional[StrictStr] = None
    org: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    slug: Optional[StrictStr] = None
    created: Optional[datetime] = Field(default=None, description="Date when enrollment began/activated")
    ended: Optional[datetime] = Field(description="Date when enrollment ended/deactivated")
    active: Optional[StrictBool] = Field(default=None, description="Whether the enrollment is active")
    metadata: Optional[Any] = None
    __properties: ClassVar[List[str]] = ["user_id", "username", "pathway_id", "pathway_uuid", "platform_key", "org", "name", "slug", "created", "ended", "active", "metadata"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PathwayEnrollmentPlus from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "ended",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if created (nullable) is None
        # and model_fields_set contains the field
        if self.created is None and "created" in self.model_fields_set:
            _dict['created'] = None

        # set to None if ended (nullable) is None
        # and model_fields_set contains the field
        if self.ended is None and "ended" in self.model_fields_set:
            _dict['ended'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PathwayEnrollmentPlus from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "user_id": obj.get("user_id"),
            "username": obj.get("username"),
            "pathway_id": obj.get("pathway_id"),
            "pathway_uuid": obj.get("pathway_uuid"),
            "platform_key": obj.get("platform_key"),
            "org": obj.get("org"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "created": obj.get("created"),
            "ended": obj.get("ended"),
            "active": obj.get("active"),
            "metadata": obj.get("metadata")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.course_grading_detail_data import CourseGradingDetailData

class TestCourseGradingDetailData(unittest.TestCase):
    """CourseGradingDetailData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CourseGradingDetailData:
        """Test CourseGradingDetailData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CourseGradingDetailData`
        """
        model = CourseGradingDetailData()
        if include_optional:
            return CourseGradingDetailData(
                display_name = '',
                id = '',
                subsections = [
                    iblai.models.course_grade_detail_sub_section.CourseGradeDetailSubSection(
                        display_name = '', 
                        id = '', 
                        attempts = '', 
                        average = '', 
                        problems = [
                            iblai.models.course_grade_detail_block.CourseGradeDetailBlock(
                                display_name = '', 
                                id = '', 
                                attempts = '', 
                                average = '', )
                            ], )
                    ]
            )
        else:
            return CourseGradingDetailData(
                display_name = '',
                id = '',
        )
        """

    def testCourseGradingDetailData(self):
        """Test CourseGradingDetailData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.service_api import ServiceApi


class TestServiceApi(unittest.TestCase):
    """ServiceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ServiceApi()

    def tearDown(self) -> None:
        pass

    def test_service_launch_tenant_create(self) -> None:
        """Test case for service_launch_tenant_create

        """
        pass

    def test_service_manage_user_create(self) -> None:
        """Test case for service_manage_user_create

        """
        pass

    def test_service_manage_user_role_create(self) -> None:
        """Test case for service_manage_user_role_create

        """
        pass

    def test_service_orgs_stripe_course_payment_callback_retrieve(self) -> None:
        """Test case for service_orgs_stripe_course_payment_callback_retrieve

        """
        pass

    def test_service_orgs_users_stripe_checkout_session_create(self) -> None:
        """Test case for service_orgs_users_stripe_checkout_session_create

        """
        pass

    def test_service_orgs_users_stripe_customer_portal_create(self) -> None:
        """Test case for service_orgs_users_stripe_customer_portal_create

        """
        pass

    def test_service_orgs_users_stripe_products_manage_create(self) -> None:
        """Test case for service_orgs_users_stripe_products_manage_create

        """
        pass

    def test_service_orgs_users_stripe_products_retrieve(self) -> None:
        """Test case for service_orgs_users_stripe_products_retrieve

        """
        pass

    def test_service_orgs_users_stripe_subscription_renewal_create(self) -> None:
        """Test case for service_orgs_users_stripe_subscription_renewal_create

        """
        pass

    def test_service_orgs_users_stripe_subscriptions_retrieve(self) -> None:
        """Test case for service_orgs_users_stripe_subscriptions_retrieve

        """
        pass

    def test_service_platforms_stripe_context_retrieve(self) -> None:
        """Test case for service_platforms_stripe_context_retrieve

        """
        pass

    def test_service_platforms_stripe_credit_topup_callback_retrieve(self) -> None:
        """Test case for service_platforms_stripe_credit_topup_callback_retrieve

        """
        pass

    def test_service_platforms_stripe_pricing_page_callback_retrieve(self) -> None:
        """Test case for service_platforms_stripe_pricing_page_callback_retrieve

        """
        pass

    def test_service_platforms_stripe_pricing_page_session_retrieve(self) -> None:
        """Test case for service_platforms_stripe_pricing_page_session_retrieve

        """
        pass

    def test_service_stripe_checkout_free_trial_create(self) -> None:
        """Test case for service_stripe_checkout_free_trial_create

        """
        pass

    def test_service_stripe_checkout_retrieve(self) -> None:
        """Test case for service_stripe_checkout_retrieve

        """
        pass

    def test_service_tenant_validation_create(self) -> None:
        """Test case for service_tenant_validation_create

        """
        pass

    def test_service_token_retrieve(self) -> None:
        """Test case for service_token_retrieve

        """
        pass

    def test_service_user_validation_create(self) -> None:
        """Test case for service_user_validation_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.skills_api import SkillsApi


class TestSkillsApi(unittest.TestCase):
    """SkillsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SkillsApi()

    def tearDown(self) -> None:
        pass

    def test_skills_orgs_skills_list(self) -> None:
        """Test case for skills_orgs_skills_list

        """
        pass

    def test_skills_orgs_skills_percentile_list(self) -> None:
        """Test case for skills_orgs_skills_percentile_list

        """
        pass

    def test_skills_orgs_skills_percentile_retrieve(self) -> None:
        """Test case for skills_orgs_skills_percentile_retrieve

        """
        pass

    def test_skills_orgs_skills_retrieve(self) -> None:
        """Test case for skills_orgs_skills_retrieve

        """
        pass

    def test_skills_orgs_skills_thresholds_create(self) -> None:
        """Test case for skills_orgs_skills_thresholds_create

        """
        pass

    def test_skills_orgs_skills_thresholds_destroy(self) -> None:
        """Test case for skills_orgs_skills_thresholds_destroy

        """
        pass

    def test_skills_orgs_skills_thresholds_partial_update(self) -> None:
        """Test case for skills_orgs_skills_thresholds_partial_update

        """
        pass

    def test_skills_orgs_skills_thresholds_retrieve(self) -> None:
        """Test case for skills_orgs_skills_thresholds_retrieve

        """
        pass

    def test_skills_orgs_skills_users_desired_skills_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_desired_skills_retrieve

        """
        pass

    def test_skills_orgs_skills_users_point_percentile_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_point_percentile_retrieve

        """
        pass

    def test_skills_orgs_skills_users_reported_skills_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_reported_skills_retrieve

        """
        pass

    def test_skills_orgs_skills_users_retrieve(self) -> None:
        """Test case for skills_orgs_skills_users_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.training import Training

class TestTraining(unittest.TestCase):
    """Training unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Training:
        """Test Training
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Training`
        """
        model = Training()
        if include_optional:
            return Training(
                id = '',
                dataset = iblai.models.data_set.DataSet(
                    id = '', 
                    platform = {
                        'key' : null
                        }, 
                    name = '', 
                    prompt = '', 
                    source_url = '', 
                    source_file = '', 
                    status = 'pending', 
                    num_data_points = 56, 
                    train_split = 0, 
                    train_file = '', 
                    test_file = '', 
                    retry_attempts = 56, 
                    error_log = '', 
                    date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                project_name = '',
                metadata = None,
                status = 'trained',
                retry_attempts = 56,
                fine_tuned_model = '',
                provider = 'openai',
                base_model_name = '',
                text_column = '',
                learning_rate = 1.337,
                batch_size = 56,
                num_epochs = 56,
                block_size = 56,
                warmup_ratio = 1.337,
                lora_r = 56,
                lora_alpha = 56,
                lora_dropout = 1.337,
                weight_decay = 1.337,
                gradient_accumulation = 56,
                use_peft = True,
                use_fp16 = True,
                use_int4 = True,
                push_to_hub = True,
                repo_id = '',
                preprocess_dataset = True,
                prompt_column = '',
                response_column = '',
                prompt_prefix = '',
                prompt_suffix = '',
                response_prefix = '',
                response_suffix = '',
                error_log = '',
                date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                platform = 56
            )
        else:
            return Training(
                dataset = iblai.models.data_set.DataSet(
                    id = '', 
                    platform = {
                        'key' : null
                        }, 
                    name = '', 
                    prompt = '', 
                    source_url = '', 
                    source_file = '', 
                    status = 'pending', 
                    num_data_points = 56, 
                    train_split = 0, 
                    train_file = '', 
                    test_file = '', 
                    retry_attempts = 56, 
                    error_log = '', 
                    date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                project_name = '',
                base_model_name = '',
                date_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                last_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                platform = 56,
        )
        """

    def testTraining(self):
        """Test Training"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PathwayGroupSuggestionDetail(BaseModel):
    """
    Response serializer for pathway group suggestion details
    """ # noqa: E501
    id: StrictInt = Field(description="The unique identifier for the group suggestion")
    group_id: StrictInt = Field(description="The ID of the group receiving the suggestion")
    group_name: StrictStr = Field(description="The name of the group receiving the suggestion")
    platform_key: StrictStr = Field(description="The platform key associated with the suggestion")
    accepted: Optional[StrictBool] = Field(default=None, description="Whether the suggestion has been accepted")
    visible: StrictBool = Field(description="Whether the suggestion is visible")
    created: datetime = Field(description="When the suggestion was created")
    modified: datetime = Field(description="When the suggestion was last modified")
    metadata: Dict[str, Any] = Field(description="Additional metadata for the suggestion")
    pathway_id: StrictStr = Field(description="The pathway ID being suggested")
    pathway_uuid: StrictStr = Field(description="The UUID of the pathway being suggested")
    pathway_name: StrictStr = Field(description="The name of the pathway being suggested")
    pathway_platform_key: StrictStr = Field(description="The platform key associated with the pathway")
    user_count: Optional[StrictInt] = Field(default=None, description="Number of users in the group")
    __properties: ClassVar[List[str]] = ["id", "group_id", "group_name", "platform_key", "accepted", "visible", "created", "modified", "metadata", "pathway_id", "pathway_uuid", "pathway_name", "pathway_platform_key", "user_count"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PathwayGroupSuggestionDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PathwayGroupSuggestionDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "group_id": obj.get("group_id"),
            "group_name": obj.get("group_name"),
            "platform_key": obj.get("platform_key"),
            "accepted": obj.get("accepted"),
            "visible": obj.get("visible"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "metadata": obj.get("metadata"),
            "pathway_id": obj.get("pathway_id"),
            "pathway_uuid": obj.get("pathway_uuid"),
            "pathway_name": obj.get("pathway_name"),
            "pathway_platform_key": obj.get("pathway_platform_key"),
            "user_count": obj.get("user_count")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class CourseAccessRequestDetail(BaseModel):
    """
    Response serializer for access request details
    """ # noqa: E501
    id: StrictInt = Field(description="The unique identifier for the access request")
    user_id: StrictInt = Field(description="The ID of the user who made the request")
    username: StrictStr = Field(description="The username of the user who made the request")
    name: StrictStr = Field(description="The full name of the user who made the request")
    approved: Optional[StrictBool] = Field(description="Whether the request has been approved (null if not reviewed)")
    reviewed: StrictBool = Field(description="Whether the request has been reviewed")
    created: datetime = Field(description="When the request was created")
    modified: datetime = Field(description="When the request was last modified")
    metadata: Optional[Dict[str, Any]] = Field(default=None, description="Additional metadata for the request")
    platform_key: StrictStr = Field(description="The platform key associated with the request")
    course_id: StrictStr = Field(description="The course ID associated with the request")
    __properties: ClassVar[List[str]] = ["id", "user_id", "username", "name", "approved", "reviewed", "created", "modified", "metadata", "platform_key", "course_id"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CourseAccessRequestDetail from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if approved (nullable) is None
        # and model_fields_set contains the field
        if self.approved is None and "approved" in self.model_fields_set:
            _dict['approved'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CourseAccessRequestDetail from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "user_id": obj.get("user_id"),
            "username": obj.get("username"),
            "name": obj.get("name"),
            "approved": obj.get("approved"),
            "reviewed": obj.get("reviewed"),
            "created": obj.get("created"),
            "modified": obj.get("modified"),
            "metadata": obj.get("metadata"),
            "platform_key": obj.get("platform_key"),
            "course_id": obj.get("course_id")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.54.3-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from iblai.models.align_mentor_bubble_enum import AlignMentorBubbleEnum
from iblai.models.mentor_settings_mentor_visibility import MentorSettingsMentorVisibility
from iblai.models.theme_enum import ThemeEnum
from typing import Optional, Set
from typing_extensions import Self

class MentorSettingsPublic(BaseModel):
    """
    MentorSettingsPublic
    """ # noqa: E501
    id: StrictInt
    display_name: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    profile_image: Optional[StrictStr] = None
    initial_message: Optional[StrictStr] = None
    suggested_message: Optional[StrictStr] = None
    theme: Optional[ThemeEnum] = None
    user_message_color: Optional[Annotated[str, Field(strict=True, max_length=7)]] = None
    mentor_bubble_color: Optional[Annotated[str, Field(strict=True, max_length=7)]] = None
    align_mentor_bubble: Optional[AlignMentorBubbleEnum] = None
    mentor: StrictStr
    mentor_slug: StrictStr
    mentor_unique_id: StrictStr
    metadata: Optional[Any]
    mentor_visibility: Optional[MentorSettingsMentorVisibility] = None
    enable_image_generation: Optional[StrictBool] = None
    enable_web_browsing: Optional[StrictBool] = None
    enable_code_interpreter: Optional[StrictBool] = None
    custom_css: Optional[StrictStr] = None
    allow_anonymous: StrictBool
    mentor_description: StrictStr
    suggested_prompts: Optional[Any]
    proactive_response: StrictStr
    greeting_method: StrictStr
    mentor_tools: Optional[Any]
    can_use_tools: StrictBool
    llm_name: StrictStr
    proactive_prompt: StrictStr
    enable_memory_component: StrictBool
    enable_email_chat: StrictBool
    enable_spaced_repetition: StrictBool
    enable_instruction_mode: StrictBool
    enable_socratic_mode: StrictBool
    is_guided_mentor: StrictBool
    enable_guided_prompts: StrictBool
    enable_moderation: StrictBool
    enable_post_processing_system: StrictBool
    enable_safety_system: StrictBool
    forkable: StrictBool
    forkable_with_training_data: StrictBool
    __properties: ClassVar[List[str]] = ["id", "display_name", "profile_image", "initial_message", "suggested_message", "theme", "user_message_color", "mentor_bubble_color", "align_mentor_bubble", "mentor", "mentor_slug", "mentor_unique_id", "metadata", "mentor_visibility", "enable_image_generation", "enable_web_browsing", "enable_code_interpreter", "custom_css", "allow_anonymous", "mentor_description", "suggested_prompts", "proactive_response", "greeting_method", "mentor_tools", "can_use_tools", "llm_name", "proactive_prompt", "enable_memory_component", "enable_email_chat", "enable_spaced_repetition", "enable_instruction_mode", "enable_socratic_mode", "is_guided_mentor", "enable_guided_prompts", "enable_moderation", "enable_post_processing_system", "enable_safety_system", "forkable", "forkable_with_training_data"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MentorSettingsPublic from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "id",
            "mentor",
            "mentor_slug",
            "mentor_unique_id",
            "metadata",
            "allow_anonymous",
            "mentor_description",
            "suggested_prompts",
            "proactive_response",
            "greeting_method",
            "mentor_tools",
            "can_use_tools",
            "llm_name",
            "proactive_prompt",
            "enable_memory_component",
            "enable_email_chat",
            "enable_spaced_repetition",
            "enable_instruction_mode",
            "enable_socratic_mode",
            "is_guided_mentor",
            "enable_guided_prompts",
            "enable_moderation",
            "enable_post_processing_system",
            "enable_safety_system",
            "forkable",
            "forkable_with_training_data",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of mentor_visibility
        if self.mentor_visibility:
            _dict['mentor_visibility'] = self.mentor_visibility.to_dict()
        # set to None if display_name (nullable) is None
        # and model_fields_set contains the field
        if self.display_name is None and "display_name" in self.model_fields_set:
            _dict['display_name'] = None

        # set to None if profile_image (nullable) is None
        # and model_fields_set contains the field
        if self.profile_image is None and "profile_image" in self.model_fields_set:
            _dict['profile_image'] = None

        # set to None if initial_message (nullable) is None
        # and model_fields_set contains the field
        if self.initial_message is None and "initial_message" in self.model_fields_set:
            _dict['initial_message'] = None

        # set to None if suggested_message (nullable) is None
        # and model_fields_set contains the field
        if self.suggested_message is None and "suggested_message" in self.model_fields_set:
            _dict['suggested_message'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if mentor_visibility (nullable) is None
        # and model_fields_set contains the field
        if self.mentor_visibility is None and "mentor_visibility" in self.model_fields_set:
            _dict['mentor_visibility'] = None

        # set to None if enable_image_generation (nullable) is None
        # and model_fields_set contains the field
        if self.enable_image_generation is None and "enable_image_generation" in self.model_fields_set:
            _dict['enable_image_generation'] = None

        # set to None if enable_web_browsing (nullable) is None
        # and model_fields_set contains the field
        if self.enable_web_browsing is None and "enable_web_browsing" in self.model_fields_set:
            _dict['enable_web_browsing'] = None

        # set to None if enable_code_interpreter (nullable) is None
        # and model_fields_set contains the field
        if self.enable_code_interpreter is None and "enable_code_interpreter" in self.model_fields_set:
            _dict['enable_code_interpreter'] = None

        # set to None if custom_css (nullable) is None
        # and model_fields_set contains the field
        if self.custom_css is None and "custom_css" in self.model_fields_set:
            _dict['custom_css'] = None

        # set to None if suggested_prompts (nullable) is None
        # and model_fields_set contains the field
        if self.suggested_prompts is None and "suggested_prompts" in self.model_fields_set:
            _dict['suggested_prompts'] = None

        # set to None if mentor_tools (nullable) is None
        # and model_fields_set contains the field
        if self.mentor_tools is None and "mentor_tools" in self.model_fields_set:
            _dict['mentor_tools'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MentorSettingsPublic from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "display_name": obj.get("display_name"),
            "profile_image": obj.get("profile_image"),
            "initial_message": obj.get("initial_message"),
            "suggested_message": obj.get("suggested_message"),
            "theme": obj.get("theme"),
            "user_message_color": obj.get("user_message_color"),
            "mentor_bubble_color": obj.get("mentor_bubble_color"),
            "align_mentor_bubble": obj.get("align_mentor_bubble"),
            "mentor": obj.get("mentor"),
            "mentor_slug": obj.get("mentor_slug"),
            "mentor_unique_id": obj.get("mentor_unique_id"),
            "metadata": obj.get("metadata"),
            "mentor_visibility": MentorSettingsMentorVisibility.from_dict(obj["mentor_visibility"]) if obj.get("mentor_visibility") is not None else None,
            "enable_image_generation": obj.get("enable_image_generation"),
            "enable_web_browsing": obj.get("enable_web_browsing"),
            "enable_code_interpreter": obj.get("enable_code_interpreter"),
            "custom_css": obj.get("custom_css"),
            "allow_anonymous": obj.get("allow_anonymous"),
            "mentor_description": obj.get("mentor_description"),
            "suggested_prompts": obj.get("suggested_prompts"),
            "proactive_response": obj.get("proactive_response"),
            "greeting_method": obj.get("greeting_method"),
            "mentor_tools": obj.get("mentor_tools"),
            "can_use_tools": obj.get("can_use_tools"),
            "llm_name": obj.get("llm_name"),
            "proactive_prompt": obj.get("proactive_prompt"),
            "enable_memory_component": obj.get("enable_memory_component"),
            "enable_email_chat": obj.get("enable_email_chat"),
            "enable_spaced_repetition": obj.get("enable_spaced_repetition"),
            "enable_instruction_mode": obj.get("enable_instruction_mode"),
            "enable_socratic_mode": obj.get("enable_socratic_mode"),
            "is_guided_mentor": obj.get("is_guided_mentor"),
            "enable_guided_prompts": obj.get("enable_guided_prompts"),
            "enable_moderation": obj.get("enable_moderation"),
            "enable_post_processing_system": obj.get("enable_post_processing_system"),
            "enable_safety_system": obj.get("enable_safety_system"),
            "forkable": obj.get("forkable"),
            "forkable_with_training_data": obj.get("forkable_with_training_data")
        })
        return _obj





# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_index_api import AiIndexApi


class TestAiIndexApi(unittest.TestCase):
    """AiIndexApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiIndexApi()

    def tearDown(self) -> None:
        pass

    def test_ai_index_orgs_users_documents_destroy(self) -> None:
        """Test case for ai_index_orgs_users_documents_destroy

        """
        pass

    def test_ai_index_orgs_users_documents_graph_train_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_graph_train_create

        """
        pass

    def test_ai_index_orgs_users_documents_pathways_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_documents_pathways_retrieve

        """
        pass

    def test_ai_index_orgs_users_documents_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_documents_retrieve

        """
        pass

    def test_ai_index_orgs_users_documents_search_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_search_create

        """
        pass

    def test_ai_index_orgs_users_documents_sources_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_sources_create

        """
        pass

    def test_ai_index_orgs_users_documents_tasks_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_documents_tasks_retrieve

        """
        pass

    def test_ai_index_orgs_users_documents_train_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_train_create

        """
        pass

    def test_ai_index_orgs_users_documents_train_retriever_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_train_retriever_create

        """
        pass

    def test_ai_index_orgs_users_documents_train_sessions_create(self) -> None:
        """Test case for ai_index_orgs_users_documents_train_sessions_create

        """
        pass

    def test_ai_index_orgs_users_documents_update(self) -> None:
        """Test case for ai_index_orgs_users_documents_update

        """
        pass

    def test_ai_index_orgs_users_resource_data_scrapped_retrieve(self) -> None:
        """Test case for ai_index_orgs_users_resource_data_scrapped_retrieve

        """
        pass

    def test_ai_index_orgs_users_resource_data_scrapped_retrieve2(self) -> None:
        """Test case for ai_index_orgs_users_resource_data_scrapped_retrieve2

        """
        pass

    def test_ai_index_webhook_scan_create(self) -> None:
        """Test case for ai_index_webhook_scan_create

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.api.ai_mentor_api import AiMentorApi


class TestAiMentorApi(unittest.TestCase):
    """AiMentorApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AiMentorApi()

    def tearDown(self) -> None:
        pass

    def test_ai_mentor_orgs_metadata_create(self) -> None:
        """Test case for ai_mentor_orgs_metadata_create

        """
        pass

    def test_ai_mentor_orgs_sessions_create(self) -> None:
        """Test case for ai_mentor_orgs_sessions_create

        """
        pass

    def test_ai_mentor_orgs_users_ai_generated_images_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_ai_generated_images_destroy

        """
        pass

    def test_ai_mentor_orgs_users_ai_generated_images_list(self) -> None:
        """Test case for ai_mentor_orgs_users_ai_generated_images_list

        """
        pass

    def test_ai_mentor_orgs_users_ai_generated_images_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_ai_generated_images_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_audio_to_text_create(self) -> None:
        """Test case for ai_mentor_orgs_users_audio_to_text_create

        """
        pass

    def test_ai_mentor_orgs_users_available_template_mentors_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_available_template_mentors_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_clear_chathistory_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_clear_chathistory_destroy

        """
        pass

    def test_ai_mentor_orgs_users_create(self) -> None:
        """Test case for ai_mentor_orgs_users_create

        """
        pass

    def test_ai_mentor_orgs_users_create_mentor_wizard_create(self) -> None:
        """Test case for ai_mentor_orgs_users_create_mentor_wizard_create

        """
        pass

    def test_ai_mentor_orgs_users_custom_instruction_create(self) -> None:
        """Test case for ai_mentor_orgs_users_custom_instruction_create

        """
        pass

    def test_ai_mentor_orgs_users_custom_instruction_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_custom_instruction_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_custom_instruction_update(self) -> None:
        """Test case for ai_mentor_orgs_users_custom_instruction_update

        """
        pass

    def test_ai_mentor_orgs_users_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_destroy

        """
        pass

    def test_ai_mentor_orgs_users_downloads_tasks_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_downloads_tasks_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_edx_memory_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_edx_memory_destroy

        """
        pass

    def test_ai_mentor_orgs_users_edx_memory_list(self) -> None:
        """Test case for ai_mentor_orgs_users_edx_memory_list

        """
        pass

    def test_ai_mentor_orgs_users_edx_memory_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_edx_memory_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_export_chathistory_create(self) -> None:
        """Test case for ai_mentor_orgs_users_export_chathistory_create

        """
        pass

    def test_ai_mentor_orgs_users_free_usage_count_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_free_usage_count_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_list(self) -> None:
        """Test case for ai_mentor_orgs_users_list

        """
        pass

    def test_ai_mentor_orgs_users_mentor_categories_create(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_categories_create

        """
        pass

    def test_ai_mentor_orgs_users_mentor_categories_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_categories_destroy

        """
        pass

    def test_ai_mentor_orgs_users_mentor_categories_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_categories_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentor_feedback_create_create(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_feedback_create_create

        """
        pass

    def test_ai_mentor_orgs_users_mentor_feedback_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_feedback_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentor_feedback_update(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_feedback_update

        """
        pass

    def test_ai_mentor_orgs_users_mentor_from_template_create(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_from_template_create

        """
        pass

    def test_ai_mentor_orgs_users_mentor_llms_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_llms_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentor_seed_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_seed_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentor_tools_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_tools_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentor_with_settings_create(self) -> None:
        """Test case for ai_mentor_orgs_users_mentor_with_settings_create

        """
        pass

    def test_ai_mentor_orgs_users_mentors_available_tools_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_available_tools_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentors_memory_component_settings_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_memory_component_settings_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentors_memory_component_settings_update(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_memory_component_settings_update

        """
        pass

    def test_ai_mentor_orgs_users_mentors_public_settings_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_public_settings_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentors_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentors_scenarios_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_scenarios_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentors_scenarios_update(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_scenarios_update

        """
        pass

    def test_ai_mentor_orgs_users_mentors_settings_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_settings_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_mentors_settings_update(self) -> None:
        """Test case for ai_mentor_orgs_users_mentors_settings_update

        """
        pass

    def test_ai_mentor_orgs_users_metadata_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_metadata_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_moderation_logs_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_moderation_logs_destroy

        """
        pass

    def test_ai_mentor_orgs_users_moderation_logs_list(self) -> None:
        """Test case for ai_mentor_orgs_users_moderation_logs_list

        """
        pass

    def test_ai_mentor_orgs_users_moderation_logs_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_moderation_logs_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_partial_update(self) -> None:
        """Test case for ai_mentor_orgs_users_partial_update

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agent_logs_list(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agent_logs_list

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agent_logs_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agent_logs_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agents_create(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agents_create

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agents_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agents_destroy

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agents_list(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agents_list

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agents_partial_update(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agents_partial_update

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agents_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agents_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_periodic_agents_update(self) -> None:
        """Test case for ai_mentor_orgs_users_periodic_agents_update

        """
        pass

    def test_ai_mentor_orgs_users_pin_message_create(self) -> None:
        """Test case for ai_mentor_orgs_users_pin_message_create

        """
        pass

    def test_ai_mentor_orgs_users_pin_message_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_pin_message_destroy

        """
        pass

    def test_ai_mentor_orgs_users_pin_message_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_pin_message_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_planned_jobs_list(self) -> None:
        """Test case for ai_mentor_orgs_users_planned_jobs_list

        """
        pass

    def test_ai_mentor_orgs_users_planned_jobs_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_planned_jobs_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_playwright_scripts_create(self) -> None:
        """Test case for ai_mentor_orgs_users_playwright_scripts_create

        """
        pass

    def test_ai_mentor_orgs_users_playwright_scripts_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_playwright_scripts_destroy

        """
        pass

    def test_ai_mentor_orgs_users_playwright_scripts_list(self) -> None:
        """Test case for ai_mentor_orgs_users_playwright_scripts_list

        """
        pass

    def test_ai_mentor_orgs_users_playwright_scripts_partial_update(self) -> None:
        """Test case for ai_mentor_orgs_users_playwright_scripts_partial_update

        """
        pass

    def test_ai_mentor_orgs_users_playwright_scripts_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_playwright_scripts_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_playwright_scripts_update(self) -> None:
        """Test case for ai_mentor_orgs_users_playwright_scripts_update

        """
        pass

    def test_ai_mentor_orgs_users_predictive_analytics_create(self) -> None:
        """Test case for ai_mentor_orgs_users_predictive_analytics_create

        """
        pass

    def test_ai_mentor_orgs_users_recent_messages_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_recent_messages_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_recommend_courses_block_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_recommend_courses_block_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_recommend_courses_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_recommend_courses_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_safety_logs_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_safety_logs_destroy

        """
        pass

    def test_ai_mentor_orgs_users_safety_logs_list(self) -> None:
        """Test case for ai_mentor_orgs_users_safety_logs_list

        """
        pass

    def test_ai_mentor_orgs_users_safety_logs_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_safety_logs_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_session_detail_mentors_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_session_detail_mentors_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessionid_list(self) -> None:
        """Test case for ai_mentor_orgs_users_sessionid_list

        """
        pass

    def test_ai_mentor_orgs_users_sessions_browser_screenshot_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_browser_screenshot_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessions_create(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_create

        """
        pass

    def test_ai_mentor_orgs_users_sessions_destroy(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_destroy

        """
        pass

    def test_ai_mentor_orgs_users_sessions_download_session_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_download_session_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessions_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessions_shell_logs_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_shell_logs_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessions_suggestion_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_suggestion_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessions_tasks_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_tasks_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_sessions_update(self) -> None:
        """Test case for ai_mentor_orgs_users_sessions_update

        """
        pass

    def test_ai_mentor_orgs_users_settings_tenant_llm_create(self) -> None:
        """Test case for ai_mentor_orgs_users_settings_tenant_llm_create

        """
        pass

    def test_ai_mentor_orgs_users_settings_tenant_llm_list(self) -> None:
        """Test case for ai_mentor_orgs_users_settings_tenant_llm_list

        """
        pass

    def test_ai_mentor_orgs_users_tasks_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_tasks_retrieve

        """
        pass

    def test_ai_mentor_orgs_users_tasks_sessions_create(self) -> None:
        """Test case for ai_mentor_orgs_users_tasks_sessions_create

        """
        pass

    def test_ai_mentor_orgs_users_update(self) -> None:
        """Test case for ai_mentor_orgs_users_update

        """
        pass

    def test_ai_mentor_orgs_users_usage_retrieve(self) -> None:
        """Test case for ai_mentor_orgs_users_usage_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    ibl-data-manager

    API for iblai

    The version of the OpenAPI document: 3.6.0-ai-plus
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from iblai.models.per_learner_last_access_data import PerLearnerLastAccessData

class TestPerLearnerLastAccessData(unittest.TestCase):
    """PerLearnerLastAccessData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PerLearnerLastAccessData:
        """Test PerLearnerLastAccessData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PerLearnerLastAccessData`
        """
        model = PerLearnerLastAccessData()
        if include_optional:
            return PerLearnerLastAccessData(
                course_last_accessed = iblai.models.per_learner_course_last_access_data.PerLearnerCourseLastAccessData(
                    course_id = '', 
                    course_name = '', 
                    block_id = '', 
                    block_display_name = '', 
                    course_grade = 1.337, 
                    course_progress = 1.337, 
                    last_accessed = '', ),
                last_accessed = ''
            )
        else:
            return PerLearnerLastAccessData(
        )
        """

    def testPerLearnerLastAccessData(self):
        """Test PerLearnerLastAccessData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
